@@ -450,14 +450,10 @@ class DistMatrix:
         (d,(i,j)), where d is the dissimilarity d(i,j).
         The entries are sorted w.r.t. accending values of d.
         '''
-        entries = [None]*(self.n*(self.n-1)//2)
-        linIndex = 0
-        for i in range(self.n):
-            for j in range(i+1, self.n):
-                entries[linIndex] = (self.dists[linIndex],(i,j))
-                linIndex += 1
-
-        key = lambda a : a[0]
+        import itertools
+        pairs   = itertools.combinations(range(self.n),2)
+        entries = zip(self.dists, pairs)
+        key     = lambda a : a[0]
         return sorted(entries, key=key)
 
     def getChunkedIndexPairs(self):
@@ -473,10 +469,6 @@ class DistMatrix:
             return []
 
         class Chunk:
-            def __init__(self):
-                self.dist  = 0
-                self.pairs = []
-
             def __str__(self):
                 return 'Chunk[%1.3f,%s]' % (self.dist, str(self.pairs))
             def __repr__(self):
@@ -515,8 +507,8 @@ class DistMatrix:
     def toMatrixIndex(self,k):
         from math import sqrt,floor
         n = self.n
-        i = n - 2 - floor(sqrt(-8*k + 4*n*(n-1)-7)/2.0 - 0.5)
-        j = k + i + 1 - n*(n-1)/2 + (n-i)*((n-i)-1)/2
+        i = n - 2 - int(floor(sqrt(-8*k + 4*n*(n-1)-7)/2.0 - 0.5))
+        j = k + i + 1 - n*(n-1)//2 + (n-i)*(n-i-1)//2
         assert i >= 0 and j >= 0
         return i,j
 
